exact2x2Pvals can calculate p-values for a vector of odds ratios.
The function exact2x2CI is the code that calculates the confidence intervals for the two-sided
Fisher's exact test and Blaker's exact test.exact2x2Pvals(x, or, relErr=1+10^(-7),tsmethod = "minlike", alternative="two.sided")
exact2x2CI(x, tsmethod="minlike", conf.level=0.95, tol=0.00001, orRange=c(10^-10,10^10))
mcnemar.exact.calc(bb,cc,or,alternative,tsmethod="central",conf.level=.95)"two.sided", "greater" or "less".exact2x2Pvals is a LIST, withexact2x2CI is a confidence interval with attributes: conf.level and conf.int.prec (a list
of the bounds on the precision of the limits).fisher.test uses relErr so that it chooses all
d<= d[i]*relerr="" and="" if="" mathematically="" d[i]="" is="" equal="" to="" another="" value="" in="" d="" but="" there="" a="" slightly="" computer="" rounding="" error,="" that="" will="" be="" included.="" we="" use="" the="" same="" tactic="" here.="" function="" mcnemar.exact.calc is just a simple call to binom.test with
p=.5.=>exact2x2